@@ -22,8 +22,6 @@
 
 #include <PimCommon/AbstractGenericPlugin>
 #include "kaddressbook_importexport_export.h"
-#include <QList>
-class QAction;
 namespace KAddressBookImportExport {
 class KADDRESSBOOK_IMPORTEXPORT_EXPORT KAddressBookImportExportPlugin : public PimCommon::AbstractGenericPlugin
 {
